@@ -5,9 +5,10 @@ from operator import sub, truediv
 from functools import reduce
 from math import sqrt, prod
 from ..http import check
+from ..base import Capylang
 
-class capy:
-  __version__ = "1.2.0"
+class capy(Capylang):
+  __version__ = "1.3.1"
   #Functions
   __doc__ = f"Capylang v{__version__}. Please check README.md for documentation. Docstrings are not easy to make." # Python int Docstring
   
